# ADR-NNN: Title

## Status
<!-- Proposed | Accepted | Superseded by ADR-XXX -->
Proposed

## Context
<!-- What is the issue that we're seeing that is motivating this decision or change? -->

## Decision
<!-- What is the change that we're proposing and/or doing? -->

## Consequences
<!-- What becomes easier or more difficult to do because of this change? -->
